# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/index_v1/commodity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/index_v1/commodity.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n\035com.kaiko.sdk.stream.index_v1P\001Z?github.com/challengerdeep/kaiko-go-sdk/stream/index_v1;index_v1\252\002\027KaikoSdk.Stream.IndexV1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#sdk/stream/index_v1/commodity.proto\x12\x08kaikosdk*P\n\x14StreamIndexCommodity\x12\x0f\n\x0bSIC_UNKNOWN\x10\x00\x12\x11\n\rSIC_REAL_TIME\x10\x01\x12\x14\n\x10SIC_DAILY_FIXING\x10\x02\x42|\n\x1d\x63om.kaiko.sdk.stream.index_v1P\x01Z?github.com/challengerdeep/kaiko-go-sdk/stream/index_v1;index_v1\xaa\x02\x17KaikoSdk.Stream.IndexV1b\x06proto3'
)

_STREAMINDEXCOMMODITY = _descriptor.EnumDescriptor(
  name='StreamIndexCommodity',
  full_name='kaikosdk.StreamIndexCommodity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SIC_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIC_REAL_TIME', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIC_DAILY_FIXING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=49,
  serialized_end=129,
)
_sym_db.RegisterEnumDescriptor(_STREAMINDEXCOMMODITY)

StreamIndexCommodity = enum_type_wrapper.EnumTypeWrapper(_STREAMINDEXCOMMODITY)
SIC_UNKNOWN = 0
SIC_REAL_TIME = 1
SIC_DAILY_FIXING = 2


DESCRIPTOR.enum_types_by_name['StreamIndexCommodity'] = _STREAMINDEXCOMMODITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/derivatives_price_v2/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.core import wrappers_pb2 as sdk_dot_core_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk/stream/derivatives_price_v2/response.proto',
  package='kaikosdk',
  syntax='proto3',
  serialized_options=b'\n)com.kaiko.sdk.stream.derivatives_price_v2P\001ZWgithub.com/challengerdeep/kaiko-go-sdk/stream/derivatives_price_v2;derivatives_price_v2\252\002\"KaikoSdk.Stream.DerivativesPriceV2',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.sdk/stream/derivatives_price_v2/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17sdk/core/wrappers.proto\"\xd6\x02\n StreamDerivativesPriceResponseV2\x12\r\n\x05\x63lass\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x10\n\x08\x65xchange\x18\x03 \x01(\t\x12\x46\n\x06values\x18\x04 \x03(\x0b\x32\x36.kaikosdk.StreamDerivativesPriceResponseV2.ValuesEntry\x12-\n\x0bts_exchange\x18\x05 \x01(\x0b\x32\x18.kaikosdk.TimestampValue\x12/\n\rts_collection\x18\x06 \x01(\x0b\x32\x18.kaikosdk.TimestampValue\x12,\n\x08ts_event\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a-\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\xab\x01\n)com.kaiko.sdk.stream.derivatives_price_v2P\x01ZWgithub.com/challengerdeep/kaiko-go-sdk/stream/derivatives_price_v2;derivatives_price_v2\xaa\x02\"KaikoSdk.Stream.DerivativesPriceV2b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,sdk_dot_core_dot_wrappers__pb2.DESCRIPTOR,])




_STREAMDERIVATIVESPRICERESPONSEV2_VALUESENTRY = _descriptor.Descriptor(
  name='ValuesEntry',
  full_name='kaikosdk.StreamDerivativesPriceResponseV2.ValuesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='kaikosdk.StreamDerivativesPriceResponseV2.ValuesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='kaikosdk.StreamDerivativesPriceResponseV2.ValuesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=416,
  serialized_end=461,
)

_STREAMDERIVATIVESPRICERESPONSEV2 = _descriptor.Descriptor(
  name='StreamDerivativesPriceResponseV2',
  full_name='kaikosdk.StreamDerivativesPriceResponseV2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='class', full_name='kaikosdk.StreamDerivativesPriceResponseV2.class', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='kaikosdk.StreamDerivativesPriceResponseV2.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='kaikosdk.StreamDerivativesPriceResponseV2.exchange', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='kaikosdk.StreamDerivativesPriceResponseV2.values', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_exchange', full_name='kaikosdk.StreamDerivativesPriceResponseV2.ts_exchange', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_collection', full_name='kaikosdk.StreamDerivativesPriceResponseV2.ts_collection', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_event', full_name='kaikosdk.StreamDerivativesPriceResponseV2.ts_event', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMDERIVATIVESPRICERESPONSEV2_VALUESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=119,
  serialized_end=461,
)

_STREAMDERIVATIVESPRICERESPONSEV2_VALUESENTRY.containing_type = _STREAMDERIVATIVESPRICERESPONSEV2
_STREAMDERIVATIVESPRICERESPONSEV2.fields_by_name['values'].message_type = _STREAMDERIVATIVESPRICERESPONSEV2_VALUESENTRY
_STREAMDERIVATIVESPRICERESPONSEV2.fields_by_name['ts_exchange'].message_type = sdk_dot_core_dot_wrappers__pb2._TIMESTAMPVALUE
_STREAMDERIVATIVESPRICERESPONSEV2.fields_by_name['ts_collection'].message_type = sdk_dot_core_dot_wrappers__pb2._TIMESTAMPVALUE
_STREAMDERIVATIVESPRICERESPONSEV2.fields_by_name['ts_event'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['StreamDerivativesPriceResponseV2'] = _STREAMDERIVATIVESPRICERESPONSEV2
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamDerivativesPriceResponseV2 = _reflection.GeneratedProtocolMessageType('StreamDerivativesPriceResponseV2', (_message.Message,), {

  'ValuesEntry' : _reflection.GeneratedProtocolMessageType('ValuesEntry', (_message.Message,), {
    'DESCRIPTOR' : _STREAMDERIVATIVESPRICERESPONSEV2_VALUESENTRY,
    '__module__' : 'sdk.stream.derivatives_price_v2.response_pb2'
    # @@protoc_insertion_point(class_scope:kaikosdk.StreamDerivativesPriceResponseV2.ValuesEntry)
    })
  ,
  'DESCRIPTOR' : _STREAMDERIVATIVESPRICERESPONSEV2,
  '__module__' : 'sdk.stream.derivatives_price_v2.response_pb2'
  # @@protoc_insertion_point(class_scope:kaikosdk.StreamDerivativesPriceResponseV2)
  })
_sym_db.RegisterMessage(StreamDerivativesPriceResponseV2)
_sym_db.RegisterMessage(StreamDerivativesPriceResponseV2.ValuesEntry)


DESCRIPTOR._options = None
_STREAMDERIVATIVESPRICERESPONSEV2_VALUESENTRY._options = None
# @@protoc_insertion_point(module_scope)
